@@ -1,6 +1,6 @@
-/* $Id: paintradar.c,v 4.12 2000/09/15 13:22:12 bert Exp $
+/* $Id: paintradar.c,v 4.16 2001/03/20 18:47:19 bert Exp $
  *
- * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-98 by
+ * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
  *      Bjrn Stabell        <bjoern@xpilot.org>
  *      Ken Ronny Schouten   <ken@xpilot.org>
@@ -22,17 +22,20 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifdef	_WINDOWS
-#include "NT/winX.h"
-#include "NT/winXXPilot.h"
-#else
-#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <errno.h>
 
-#include <X11/Xlib.h>
-#include <X11/Xos.h>
+#ifndef _WINDOWS
+# include <unistd.h>
+# include <X11/Xlib.h>
+# include <X11/Xos.h>
+#endif
+
+#ifdef _WINDOWS
+# include "NT/winX.h"
+# include "NT/winXXPilot.h"
 #endif
 
 #include "version.h"
@@ -74,7 +77,7 @@ static int	slidingradar_y;
 
 static void Copy_static_radar(void)
 {
-#ifndef	_WINDOWS
+#ifndef _WINDOWS
     if (s_radar != p_radar) {
 	/* Draw static radar onto radar */
 	XCopyArea(dpy, s_radar, p_radar, gc,
@@ -93,7 +96,7 @@ static void Copy_static_radar(void)
 }
 
 
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 static void Windows_copy_sliding_radar(float xf, float yf)
 {
     slidingradar_x = (int)((pos.x * xf + 0.5) + 128) % 256;
@@ -265,15 +268,19 @@ void Paint_radar(void)
     slidingradar_x = 0;
     slidingradar_y = 0;
 
-    Copy_static_radar();
-
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
     if (BIT(instruments, SHOW_SLIDING_RADAR) != 0) {
 	/*
 	 * Hack to fix slidingradar in windows.
 	 */
 	Windows_copy_sliding_radar(xf, yf);
     }
+    else
+    {
+	Copy_static_radar();
+    }
+#else
+    Copy_static_radar();
 #endif
 
     /* Checkpoints */
@@ -334,7 +341,7 @@ void Paint_world_radar(void)
 
     radar_exposures = 2;
 
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
     XSetForeground(dpy, s_radar, colors[BLACK].pixel);
     XFillRectangle(dpy, s_radar, radarGC, 0, 0, 256, RadarHeight);
 #else
@@ -450,7 +457,7 @@ void Paint_world_radar(void)
 			}
 			start = end = yp;
 			currColor = visibleColor[type];
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 			XSetForeground(dpy, s_radar, currColor);
 #else
 			XSetForeground(dpy, radarGC, colors[currColor].pixel);
@@ -539,7 +546,7 @@ void Paint_world_radar(void)
 			}
 			start = end = yp;
 			currColor = visibleColor[type];
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 			XSetForeground(dpy, s_radar, currColor);
 #else
 			XSetForeground(dpy, radarGC, colors[currColor].pixel);
@@ -589,7 +596,7 @@ void Paint_world_radar(void)
 		    }
 		    start = end = yp;
 		    currColor = visibleColor[type];
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 		    XSetForeground(dpy, s_radar, currColor);
 #else
 		    XSetForeground(dpy, radarGC, colors[currColor].pixel);
