@@ -1,6 +1,6 @@
-/* $Id: widget.c,v 4.1 1998/04/16 17:39:50 bert Exp $
+/* $Id: widget.c,v 4.10 2001/03/20 18:47:19 bert Exp $
  *
- * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-98 by
+ * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
  *      Bjrn Stabell        <bjoern@xpilot.org>
  *      Ken Ronny Schouten   <ken@xpilot.org>
@@ -22,22 +22,23 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifdef	_WINDOWS
-#include "NT/winX.h"
-#include "NT/winClient.h"
-#include "NT/winXXPilot.h"
-#else
-
-#include <X11/Xlib.h>
-#include <X11/Xos.h>
-#include <X11/Xutil.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <errno.h>
 #include <string.h>
 #include <limits.h>
+
+#ifndef _WINDOWS
+# include <X11/Xlib.h>
+# include <X11/Xos.h>
+# include <X11/Xutil.h>
+#endif
+
+#ifdef _WINDOWS
+# include "NT/winX.h"
+# include "NT/winClient.h"
+# include "NT/winXXPilot.h"
 #endif
 
 #include "version.h"
@@ -119,6 +120,29 @@ static void Widget_destroy_viewer(widget_t *w)
     v->line = NULL;
 }
 
+void Widget_destroy_children(int widget_desc)
+{
+    int			i;
+    widget_t		*w;
+    widget_form_t	*form;
+
+    if ((w = Widget_pointer(widget_desc)) != NULL) {
+	if (w->type == WIDGET_FORM) {
+	    if (w->sub != NULL) {
+		form = (widget_form_t *) w->sub;
+		if (form->children != NULL) {
+		    for (i = 0; i < form->num_children; i++) {
+			Widget_destroy(form->children[i]);
+		    }
+		    free(form->children);
+		    form->children = NULL;
+		    form->num_children = 0;
+		}
+	    }
+	}
+    }
+}
+
 void Widget_destroy(int widget_desc)
 {
     int			i;
@@ -196,7 +220,7 @@ static widget_t *Widget_new(int *descp)
 	max_widgets = 10;
 	widgets = (widget_t *) malloc(max_widgets * sizeof(widget_t));
     } else {
-	max_widgets += 10;
+	max_widgets = 10 + (12 * max_widgets) / 8;
 	widgets = (widget_t *) realloc(widgets,
 				       max_widgets * sizeof(widget_t));
     }
@@ -253,7 +277,7 @@ static int Widget_add_child(int parent_desc, int child_desc)
     widget_t		*parent,
 			*child;
     widget_form_t	*form;
-    const int		incr = 1;
+    int			incr;
 
     if ((parent = Widget_pointer(parent_desc)) == NULL
 	|| (child = Widget_pointer(child_desc)) == NULL) {
@@ -280,9 +304,11 @@ static int Widget_add_child(int parent_desc, int child_desc)
 	}
     }
     if (form->num_children == 0) {
+	incr = 4;
 	form->children = (int *) malloc((form->num_children + incr)
 					* sizeof(*form->children));
     } else {
+	incr = 4 + form->num_children / 2;
 	form->children = (int *) realloc(form->children,
 					 (form->num_children + incr)
 					 * sizeof(*form->children));
@@ -298,7 +324,7 @@ static int Widget_add_child(int parent_desc, int child_desc)
 	}
 	form->children[form->num_children] = child_desc;
 	child->parent_desc = parent_desc;
-	form->num_children += incr;
+	form->num_children++;
     }
     return child_desc;
 }
@@ -590,6 +616,8 @@ static void Widget_draw_expose(int widget_desc, XExposeEvent *expose)
 	return;
     }
 
+    /* printf("exp wd %d, wt %d\n", widget_desc, widget->type); */
+
     switch (widget->type) {
 
     case WIDGET_FORM:
@@ -644,7 +672,7 @@ static void Widget_draw_expose(int widget_desc, XExposeEvent *expose)
 	    break;
 	intw = (widget_int_t *) widget->sub;
 	sprintf(buf, "%d", *intw->val);
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 	SET_FG(WHITE);
 #endif
 	Widget_draw_input(widget, buf);
@@ -662,7 +690,7 @@ static void Widget_draw_expose(int widget_desc, XExposeEvent *expose)
 	} else {
 	    sprintf(buf, "%d", (int) *floatw->val);
 	}
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 	SET_FG(WHITE);
 #endif
 	Widget_draw_input(widget, buf);
@@ -1008,6 +1036,15 @@ static void Widget_button(XEvent *event, int widget_desc, bool pressed)
 			    Widget_draw(sub_widget_desc);
 			}
 		    }
+#ifdef _WINDOWS
+		    {
+			widget_t* widget = Widget_pointer(sub_widget_desc);
+			WinXFlush(widget->window);
+			widget = Widget_pointer(widget_desc);
+			WinXFlush(widget->window);
+		    }
+#endif
+
 		}
 		break;
 	    case WIDGET_INPUT_FLOAT:
@@ -1061,7 +1098,7 @@ static void Widget_button(XEvent *event, int widget_desc, bool pressed)
 			    Widget_draw(sub_widget_desc);
 			}
 		    }
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
 		    {
 			widget_t* widget = Widget_pointer(sub_widget_desc);
 			WinXFlush(widget->window);
@@ -1153,10 +1190,10 @@ int Widget_event(XEvent *event)
     widget_arrow_t	*arroww;
     widget_slider_t	*sliderw;
 
-	/* xpprintf("Widget_event type=%d w=%d\n", event->type, event->xany.window); */
+    /* xpprintf("Widget_event type=%d w=%d\n", event->type, event->xany.window); */
 
-	if (!widgets)
-		return(0);
+    if (!widgets)
+	return(0);
 
     if (event->type == ButtonRelease) {
 	if (event->xbutton.button == Button1) {
@@ -1786,7 +1823,7 @@ int Widget_create_popup(int width, int height, int border,
 	sattr.colormap = colormap;
 	mask |= CWColormap;
     }
-#ifdef	_WINDOWS
+#ifdef _WINDOWS
     border = 3;			/* make it a popup w/title window */
 #endif
     window = XCreateWindow(dpy,
@@ -1875,6 +1912,19 @@ int Widget_backing_store(int widget_desc, int mode)
     return widget_desc;
 }
 
+int Widget_set_background(int widget_desc, int bgcolor)
+{
+    XSetWindowAttributes	sattr;
+    widget_t			*widget;
+
+    if ((widget = Widget_pointer(widget_desc)) == NULL) {
+	return NO_WIDGET;
+    }
+    sattr.background_pixel = colors[bgcolor].pixel;
+    XChangeWindowAttributes(dpy, widget->window, CWBackPixel, &sattr);
+    return widget_desc;
+}
+
 int Widget_map_sub(int widget_desc)
 {
     widget_t		*widget;
@@ -1931,6 +1981,19 @@ int Widget_raise(int widget_desc)
     return widget_desc;
 }
 
+int Widget_get_dimensions(int widget_desc, int *width, int *height)
+{
+    widget_t		*widget;
+
+    if ((widget = Widget_pointer(widget_desc)) != NULL) {
+	if (width) *width = widget->width;
+	if (height) *height = widget->height;
+    } else {
+	return NO_WIDGET;
+    }
+    return widget_desc;
+}
+
 static int Widget_create_slider(int parent_desc, widget_type_t slider_type,
 				int x, int y, int width, int height,
 				int border, int viewer_desc)
@@ -2163,8 +2226,7 @@ int Widget_create_viewer(const char *buf, int len,
 			 const char *window_name, const char *icon_name,
 			 XFontStruct *font)
 {
-    const int
-			save_width = 2*8 + XTextWidth(font, "SAVE", 5),
+    const int		save_width = 2*8 + XTextWidth(font, "SAVE", 5),
 			save_height = 6 + font->ascent + font->descent,
 			save_x_offset = width / 3 - save_width / 2,
 			save_y_offset = 5,
