@@ -1,4 +1,4 @@
-/* $Id: xp-replay.c,v 4.5 2000/03/24 12:47:02 bert Exp $
+/* $Id: xp-replay.c,v 4.6 2001/03/20 14:02:49 bert Exp $
  *
  * XP-Replay, playback an XPilot session.  Copyright (C) 1994-98 by
  *
@@ -34,35 +34,45 @@
 ** implied warranty.
  */
 
-#ifdef VMS
-#include <socket.h>
+#if !defined(_WINDOWS) && !defined(VMS)
+# include <unistd.h>
 #endif
-#include <unistd.h>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <signal.h>
 #include <errno.h>
 #include <math.h>
-#include <sys/time.h>
-#include <sys/types.h>
+#include <time.h>
 #include <sys/stat.h>
-#ifdef _AIX
-#include <sys/select.h> /* _BSD not defined in <sys/types.h>, so done by hand */
+#include <sys/types.h>
+
+#ifndef _WINDOWS
+# ifndef __hpux
+#  include <sys/time.h>
+# endif
+# ifdef VMS
+#  include <socket.h>
+# endif
+# ifdef _AIX
+#  include <sys/select.h> /* _BSD not defined in <sys/types.h>, so done by hand */
+# endif
+# include <stdarg.h>
+# include <X11/Xlib.h>
+# include <X11/Xutil.h>
+# if !defined(select) && defined(__linux__)
+#  define select(N, R, W, E, T)   select((N),             \
+        (fd_set*)(R), (fd_set*)(W), (fd_set*)(E), (T))
+# endif
 #endif
-#include <stdarg.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
+
 #ifdef _SEQUENT_
-#include <sys/procstats.h>
-#define gettimeofday(T,X)	get_process_stats(T, PS_SELF, \
+# include <sys/procstats.h>
+# define gettimeofday(T,X)	get_process_stats(T, PS_SELF, \
 					(struct process_stats *)NULL, \
 					(struct process_stats *)NULL)
 #endif
-#if !defined(select) && defined(__linux__)
-#define select(N, R, W, E, T)   select((N),             \
-        (fd_set*)(R), (fd_set*)(W), (fd_set*)(E), (T))
-#endif
 
 #include "recordfmt.h"
 #include "item.h"
