@@ -1,6 +1,6 @@
-/* $Id: contact.c,v 4.11 2000/09/06 13:26:06 bert Exp $
+/* $Id: contact.c,v 4.19 2001/03/27 12:50:33 bert Exp $
  *
- * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-98 by
+ * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
  *      Bjrn Stabell        <bjoern@xpilot.org>
  *      Ken Ronny Schouten   <ken@xpilot.org>
@@ -22,21 +22,25 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifdef	_WINDOWS
-#include "NT/winServer.h"
-#include <time.h>
-#include <process.h>
-#include <limits.h>
-#else
-#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <stdio.h>
 #include <time.h>
-#if !defined(__hpux)
-#include <sys/time.h>
+#include <errno.h>
+#include <limits.h>
+#include <sys/types.h>
+
+#ifndef _WINDOWS
+# include <unistd.h>
+# ifndef __hpux
+#  include <sys/time.h>
+# endif
 #endif
+
+#ifdef _WINDOWS
+# include "NT/winServer.h"
+# include <process.h>
 #endif
 
 #define SERVER
@@ -56,12 +60,14 @@
 #include "error.h"
 #include "checknames.h"
 #include "server.h"
+#include "commonproto.h"
+#include "portability.h"
 
 char contact_version[] = VERSION;
 
 #ifndef	lint
 static char sourceid[] =
-    "@(#)$Id: contact.c,v 4.11 2000/09/06 13:26:06 bert Exp $";
+    "@(#)$Id: contact.c,v 4.19 2001/03/27 12:50:33 bert Exp $";
 #endif
 
 /*
@@ -71,11 +77,10 @@ int			NumQueuedPlayers = 0;
 int			MaxQueuedPlayers = 20;
 int			NumPseudoPlayers = 0;
 
-static int		contactSocket;
+sock_t			contactSocket;
+
 static sockbuf_t	ibuf;
 static char		msg[MSG_LEN];
-extern time_t		gameOverTime;
-extern time_t		serverTime;
 extern int		login_in_progress;
 extern char		ShutdownReason[];
 
@@ -91,39 +96,36 @@ static int Queue_player(char *real, char *nick, char *disp, int team,
 void Contact(int fd, void *arg);
 static int Check_address(char *addr);
 
-#ifdef	_WINDOWS
-#define	getpid()	_getpid()
-#endif
 
 void Contact_cleanup(void)
 {
-    DgramClose(contactSocket);
-    contactSocket = -1;
+    sock_close(&contactSocket);
 }
 
-int Contact_init(void)
+void Contact_init(void)
 {
+    int		status;
+
     /*
      * Create a socket which we can listen on.
      */
-    SetTimeout(0, 0);
-    if ((contactSocket = CreateDgramSocket(contactPort)) == -1) {
+    if ((status = sock_open_udp(&contactSocket, serverAddr,
+			        contactPort)) == -1) {
 	error("Could not create Dgram contactSocket");
 	End_game();
     }
-    if (SetSocketNonBlocking(contactSocket, 1) == -1) {
+    sock_set_timeout(&contactSocket, 0, 0);
+    if (sock_set_non_blocking(&contactSocket, 1) == -1) {
 	error("Can't make contact socket non-blocking");
 	End_game();
     }
-    if (Sockbuf_init(&ibuf, contactSocket, SERVER_SEND_SIZE,
+    if (Sockbuf_init(&ibuf, &contactSocket, SERVER_SEND_SIZE,
 		     SOCKBUF_READ | SOCKBUF_WRITE | SOCKBUF_DGRAM) == -1) {
 	error("No memory for contact buffer");
 	End_game();
     }
 
-    install_input(Contact, contactSocket, 0);
-
-    return contactSocket;
+    install_input(Contact, contactSocket.fd, (void *) &contactSocket);
 }
 
 /*
@@ -223,8 +225,8 @@ static int Reply(char *host_addr, int port)
     const int		max_send_retries = 3;
 
     for (i = 0; i < max_send_retries; i++) {
-	if ((result = DgramSend(ibuf.sock, host_addr, port, ibuf.buf, ibuf.len)) == -1) {
-	    GetSocketError(ibuf.sock);
+	if ((result = sock_send_dest(&ibuf.sock, host_addr, port, ibuf.buf, ibuf.len)) == -1) {
+	    sock_get_error(&ibuf.sock);
 	} else {
 	    break;
 	}
@@ -295,7 +297,7 @@ void Contact(int fd, void *arg)
 			max_robots,
     			qpos,
 			status;
-	char	reply_to;
+    char		reply_to;
     unsigned		magic,
 			version,
 			my_magic;
@@ -312,7 +314,7 @@ void Contact(int fd, void *arg)
      * Someone connected to us, now try and decipher the message :)
      */
     Sockbuf_clear(&ibuf);
-    if ((bytes = DgramReceiveAny(contactSocket, ibuf.buf, ibuf.size)) <= 8) {
+    if ((bytes = sock_receive_any(&contactSocket, ibuf.buf, ibuf.size)) <= 8) {
 	if (bytes < 0
 	    && errno != EWOULDBLOCK
 	    && errno != EAGAIN
@@ -320,13 +322,13 @@ void Contact(int fd, void *arg)
 	    /*
 	     * Clear the error condition for the contact socket.
 	     */
-	    GetSocketError(contactSocket);
+	    sock_get_error(&contactSocket);
 	}
 	return;
     }
     ibuf.len = bytes;
 
-    strcpy(host_addr, DgramLastaddr());
+    strcpy(host_addr, sock_get_last_addr(&contactSocket));
     if (Check_address(host_addr)) {
 	return;
     }
@@ -352,7 +354,7 @@ void Contact(int fd, void *arg)
     reply_to = (ch & 0xFF);	/* no sign extension. */
 
     /* ignore port for termified clients. */
-    port = DgramLastport();
+    port = sock_get_last_port(&contactSocket);
 
     /*
      * Now see if we have the same (or a compatible) version.
@@ -381,10 +383,10 @@ void Contact(int fd, void *arg)
 	static long		credentials;
 
 	if (!credentials) {
-	    credentials = (time(NULL) * (time_t)getpid());
+	    credentials = (time(NULL) * (time_t)Get_process_id());
 	    credentials ^= (long)Contact;
 	    credentials	+= (long)key + (long)&key;
-	    credentials ^= (long)rand() << 1;
+	    credentials ^= (long)randomMT() << 1;
 	    credentials &= 0xFFFFFFFF;
 	}
 	if (Packet_scanf(&ibuf, "%ld", &key) <= 0) {
@@ -1177,7 +1179,7 @@ static int Check_address(char *str)
     unsigned long	addr;
     int			i;
 
-    addr = GetInetAddr(str);
+    addr = sock_get_inet_by_addr(str);
     if (addr == (unsigned long) -1 && strcmp(str, "255.255.255.255")) {
 	return -1;
     }
@@ -1203,7 +1205,7 @@ void Set_deny_hosts(void)
 	free(addr_mask_list);
 	addr_mask_list = 0;
     }
-    if (!(list = strdup(denyHosts))) {
+    if (!(list = xp_strdup(denyHosts))) {
 	return;
     }
     for (tok = strtok(list, list_sep); tok; tok = strtok(NULL, list_sep)) {
@@ -1216,7 +1218,7 @@ void Set_deny_hosts(void)
 	slash = strchr(tok, '/');
 	if (slash) {
 	    *slash = '\0';
-	    mask = GetInetAddr(slash + 1);
+	    mask = sock_get_inet_by_addr(slash + 1);
 	    if (mask == (unsigned long) -1 && strcmp(slash + 1, "255.255.255.255")) {
 		continue;
 	    }
@@ -1226,7 +1228,7 @@ void Set_deny_hosts(void)
 	} else {
 	    mask = 0xFFFFFFFF;
 	}
-	addr = GetInetAddr(tok);
+	addr = sock_get_inet_by_addr(tok);
 	if (addr == (unsigned long) -1 && strcmp(tok, "255.255.255.255")) {
 	    continue;
 	}
